# Source code of the dataset toolkit for PartNeXt
Official dataset toolkit for _PartNeXt: A Next-Generation Dataset for Fine-Grained and Hierarchical 3D Part Understanding_.

<div align="center">

[![arXiv](https://img.shields.io/badge/arXiv-Paper-red?logo=arxiv&logoColor=white)](https://authoritywang.github.io/partnext/)
[![Project Page](https://img.shields.io/badge/Project_Page-Website-green?logo=homepage&logoColor=white)](https://authoritywang.github.io/partnext/)
[![🤗 Hugging Face Dataset](https://img.shields.io/badge/%F0%9F%A4%97%20Hugging%20Face-Dataset-blue)](https://huggingface.co/datasets/AuWang/PartNeXt)

**[Penghao Wang](https://authoritywang.github.io/), Yiyan He, Xin Lv, Yukai Zhou, [Lan Xu](https://www.xu-lan.com/), [Jingyi Yu](http://www.yu-jingyi.com/cv/), [Jiayuan Gu†](https://jiayuan-gu.github.io/)**

**ShanghaiTech University**

**Neurips 2025 Dataset and Benchmark Track**

| [Project Page](https://authoritywang.github.io/partnext/) | [Paper]() | [Dataset](https://huggingface.co/datasets/AuWang/PartNeXt) | [Dataset Toolkit]() | [Benchmark code (Soon)]() | [Annotation code (Soon)]() |<br>

</div>

## Usage

Please refer to [PartNeXt](https://github.com/AuthorityWang/PartNeXt) repo for usage of this lib. 

## Acknowledgement
Our PartNeXt dataset is based on [Objaverse](https://objaverse.allenai.org/), [ABO](https://amazon-berkeley-objects.s3.amazonaws.com/index.html), [3D-Future](https://tianchi.aliyun.com/dataset/98063), thanks for these awesome datasets. If there is any license issue, please contact us and we will remove the data. 

Thanks for Benyuan AI data for data annotation. 

If you find our dataset useful in your research, please consider citing our paper.
```
BibTex Coming Soon
```